################################################################################
#
# File:           wviewhtmlconfig.sh
#
# Description:    Provide a script to interactively configure wview HTML 
#                 templates.
#
# Usage:          (must be root)
#                 wviewhtmlconfig
#
# History:
# Engineer	  Date	    Ver   Comments
# MS Teel	  02/05/08   1    Original
#
################################################################################


################################################################################
#################################  M A C R O S  ################################
################################################################################
DATA_EXTENDED=`$WVIEWCONFIG get | grep "EXTENDED_DATA" | awk -F '=' '{print $2}'`
STATION_METRIC=`$WVIEWCONFIG get | grep "METRIC_UNITS" | awk -F '=' '{print $2}'`
HTML_DESTINATION=`$WVIEWCONFIG get | grep "IMAGE_PATH" | awk -F '=' '{print $2}'`
SITE_SKIN=classic


################################################################################
#######################  D E F I N E  F U N C T I O N S  #######################
################################################################################

show_skins()
{
    echo ""
    echo "wview site skins currently supported:"
    echo "    classic - default wview skin"
    echo "    [More choices as others contribute them]"
}

interactive_intro()
{
    echo "################################################################################"
    echo " !!!!!!!!!!!!!!!!         READ THIS BEFORE PROCEEDING         !!!!!!!!!!!!!!!!"
    echo ""
    echo "--> HTML Template Configuration for wview"
    echo ""
    echo "--> Note: This script will save existing templates to $WVIEW_CONF_DIR/html-YYYYMMDD.HHmmSS"
    echo "          before writing the new files based on your answers here - if that"
    echo "          is not what you want, hit CTRL-C now to abort this script!"
    echo ""
    echo "################################################################################"
    echo ""
    echo -n "pausing 5 seconds "
    sleep 1
    echo -n "."
    sleep 1
    echo -n "."
    sleep 1
    echo -n "."
    sleep 1
    echo -n "."
    sleep 1
    echo "."
    echo ""
}

save_old()
{
    OLD_HTML_SAVE=`date '+%Y%m%d.%H%M%S'`
    echo "Saving old HTML directory to html-$OLD_HTML_SAVE ..."
    cp -rf $WVIEW_CONF_DIR/html $WVIEW_CONF_DIR/html-$OLD_HTML_SAVE
    echo "...done."
    echo "Saving old config files..."
    if [ -f $WVIEW_CONF_DIR/html-templates.conf ]; then
        mv $WVIEW_CONF_DIR/html-templates.conf $WVIEW_CONF_DIR/html-templates.conf-$OLD_HTML_SAVE
    fi
    if [ -f $WVIEW_CONF_DIR/images.conf ]; then
        mv $WVIEW_CONF_DIR/images.conf $WVIEW_CONF_DIR/images.conf-$OLD_HTML_SAVE
    fi
    if [ -f $WVIEW_CONF_DIR/images-user.conf ]; then
        mv $WVIEW_CONF_DIR/images-user.conf $WVIEW_CONF_DIR/images-user.conf-$OLD_HTML_SAVE
    fi
    if [ -f $WVIEW_CONF_DIR/graphics.conf ]; then
        mv $WVIEW_CONF_DIR/graphics.conf $WVIEW_CONF_DIR/graphics.conf-$OLD_HTML_SAVE
    fi
    if [ -f $WVIEW_CONF_DIR/pre-generate.sh ]; then
        mv $WVIEW_CONF_DIR/pre-generate.sh $WVIEW_CONF_DIR/pre-generate.sh-$OLD_HTML_SAVE
    fi
    if [ -f $WVIEW_CONF_DIR/post-generate.sh ]; then
        mv $WVIEW_CONF_DIR/post-generate.sh $WVIEW_CONF_DIR/post-generate.sh-$OLD_HTML_SAVE
    fi
    echo "... done."
}

get_user_preferences()
{
    echo ""
    echo "---------------------------------------------------------------------------" 
    echo "Which template skin do you want to use for your site?"
    show_skins
    echo -n "($SITE_SKIN): "
    read INVAL
    if [ "" != "$INVAL" ]; then
        SITE_SKIN=$INVAL
    fi
    case "$SITE_SKIN" in
        "classic" )
            echo "Site skin $SITE_SKIN selected..."
            ;;
        *)
            echo "$SITE_SKIN not supported!"
            show_skins
            echo "Aborting - run wviewhtmlconfig again and select a valid skin..."
            exit 1
            ;;
    esac

    if [ "1" = "$DATA_EXTENDED" ]; then
        echo "With extended data graphics."
    else
        echo "With NO extended data graphics."
    fi
    if [ "1" = "$STATION_METRIC" ]; then
        echo "With metric units."
    else
        echo "With US/Imperial units."
    fi
}

move_templates()
{
    rm -rf $WVIEW_CONF_DIR/html/*.*
    if [ "1" = "$DATA_EXTENDED" ]; then
        cp -rf $WVIEW_CONF_DIR/html/$SITE_SKIN/plus/*.* $WVIEW_CONF_DIR/html
    else
        cp -rf $WVIEW_CONF_DIR/html/$SITE_SKIN/standard/*.* $WVIEW_CONF_DIR/html
    fi

    if [ -d $WVIEW_CONF_DIR/html/$SITE_SKIN/static ]; then
        cp -rf $WVIEW_CONF_DIR/html/$SITE_SKIN/static/*.* $HTML_DESTINATION
    fi
}

setup_conf_files()
{
    cp -f $WVIEW_CONF_DIR/html/html-templates.conf $WVIEW_CONF_DIR
    cp -f $WVIEW_CONF_DIR/html/pre-generate.sh $WVIEW_CONF_DIR
	chmod +x $WVIEW_CONF_DIR/pre-generate.sh
    cp -f $WVIEW_CONF_DIR/html/post-generate.sh $WVIEW_CONF_DIR
	chmod +x $WVIEW_CONF_DIR/post-generate.sh
    cp -f $WVIEW_CONF_DIR/html/images-user.conf $WVIEW_CONF_DIR
    cp -f $WVIEW_CONF_DIR/html/graphics.conf $WVIEW_CONF_DIR
    if [ "1" = "$STATION_METRIC" ]; then
        cp -f $WVIEW_CONF_DIR/html/images-metric.conf $WVIEW_CONF_DIR/images.conf
        cp -f $WVIEW_CONF_DIR/html/awekas_wl.htx-metric $WVIEW_CONF_DIR/html/awekas_wl.htx
    else
        cp -f $WVIEW_CONF_DIR/html/images.conf $WVIEW_CONF_DIR/images.conf
        cp -f $WVIEW_CONF_DIR/html/awekas_wl.htx-us $WVIEW_CONF_DIR/html/awekas_wl.htx
    fi
}

################################################################################
##################  S C R I P T  E X E C U T I O N  S T A R T  #################
################################################################################

interactive_intro
get_user_preferences
save_old
move_templates
setup_conf_files
echo "HTML setup complete:"
echo "you may now customize template files in $WVIEW_CONF_DIR/html"

